@@ -108,7 +108,6 @@ Named with \"--do-\" so transient.el recognizes it as a pre-command function."
     ("x a" "Export as ASCII" org-gtd-graph-export-ascii)]
    ["Session"
     ("I" "Incubate project" org-gtd-graph-incubate-project :transient nil)
-    ("S" "Someday/Maybe" org-gtd-graph-someday-project :transient nil)
     ("C" "Cancel project" org-gtd-graph-cancel-project :transient nil)
     ("q" "Quit menu" transient-quit-one :transient nil)
     ("Q" "Quit and kill buffer" org-gtd-graph-quit-and-kill :transient nil)
@@ -891,15 +890,6 @@ Prompts for a review date, then closes the graph view."
   (org-gtd-graph-ui-cleanup-windows)
   (quit-window))
 
-(defun org-gtd-graph-someday-project ()
-  "Put the current project on someday/maybe from graph mode.
-Prompts for someday list if configured, then closes the graph view."
-  (interactive)
-  (org-gtd-project-someday-from-context)
-  ;; Clean up details pane before quitting
-  (org-gtd-graph-ui-cleanup-windows)
-  (quit-window))
-
 (defun org-gtd-graph-cancel-project ()
   "Cancel the current project being viewed in graph mode.
 Prompts for confirmation, then closes the graph view."
