@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-gtd" "4.6.1"
+(define-package "org-gtd" "20260123.233"
   "An implementation of GTD."
   '((emacs     "28.1")
     (compat    "30.0.0.0")
@@ -9,7 +9,7 @@
     (transient "0.11.0")
     (dag-draw  "1.0.4"))
   :url "https://github.com/Trevoke/org-gtd.el"
-  :commit "1b93028024f587b3da133b4bcae473f92bb60bb6"
-  :revdesc "1b93028024f5"
+  :commit "23022e302663c9678c40429af208c8fe5774f411"
+  :revdesc "23022e302663"
   :authors '(("Aldric Giacomoni" . "trevoke@gmail.com"))
   :maintainers '(("Aldric Giacomoni" . "trevoke@gmail.com")))
