@@ -31,7 +31,6 @@
 (require 'org-clock)
 (require 'org-element)
 (require 'org-edna)
-(require 'seq)
 
 (require 'org-gtd-core)
 (require 'org-gtd-refile)
@@ -49,13 +48,6 @@
 (defvar org-gtd-graph-view--project-marker)
 (defvar org-gtd-graph-view--graph)
 
-;; Defined in org-gtd-someday.el - forward declared to avoid circular dependency.
-(defvar org-gtd-someday-lists)
-
-;; Dynamically bound by org-mode during state change hooks
-(defvar org-state)
-(defvar org-last-state)
-
 ;;;; External Function Declarations
 
 ;; Functions from org-gtd-context.el (loaded lazily in DWIM commands)
@@ -121,48 +113,6 @@ instead.")
   "\\s-*\\[\\([0-9]+\\)/\\([0-9]+\\)\\]\\[\\([0-9]+\\)%\\]\\s-*"
   "Regexp matching progress cookies [N/M][P%].")
 
-(defvar org-gtd-project--cancel-in-progress nil
-  "Guard variable to prevent re-entrant cancellation prompts.
-When non-nil, the `org-after-todo-state-change-hook' handler for
-project cancellation is suppressed.")
-
-(defun org-gtd-project--cancel-children ()
-  "Cancel all incomplete child tasks of project at point.
-Sets the guard variable, disables org-edna, cancels incomplete tasks,
-saves buffer, and cleans up.  Must be called with point on project heading."
-  (setq org-gtd-project--cancel-in-progress t)
-  (unwind-protect
-      (progn
-        (org-edna-mode -1)
-        (let ((task-markers (org-gtd-dependencies-collect-project-tasks (point-marker))))
-          (dolist (task-marker task-markers)
-            (org-with-point-at task-marker
-              (when (org-gtd-projects--incomplete-task-p)
-                (let ((org-inhibit-logging 'note))
-                  (org-todo (org-gtd-keywords--canceled)))))))
-        (save-buffer))
-    (org-edna-mode 1)
-    (setq org-gtd-project--cancel-in-progress nil)))
-
-(defun org-gtd-project--maybe-cancel-from-hook ()
-  "Hook function for `org-after-todo-state-change-hook'.
-When a project heading is changed to CNCL, prompts for confirmation
-and cancels child tasks.  If declined, reverts the heading state."
-  (unless org-gtd-project--cancel-in-progress
-    (when (and (equal org-state (org-gtd-keywords--canceled))
-               (equal (org-entry-get (point) "ORG_GTD")
-                      (org-gtd-type-org-gtd-value 'project)))
-      (let ((heading-name (org-get-heading t t t t)))
-        (if (yes-or-no-p (format "Cancel project '%s'? " heading-name))
-            (org-gtd-project--cancel-children)
-          ;; User declined: revert heading to previous state
-          (when org-last-state
-            (setq org-gtd-project--cancel-in-progress t)
-            (unwind-protect
-                (let ((org-inhibit-logging 'note))
-                  (org-todo org-last-state))
-              (setq org-gtd-project--cancel-in-progress nil))))))))
-
 ;;;; Context Helpers
 
 (defun org-gtd-project--get-marker-at-point (&optional prompt)
@@ -349,17 +299,6 @@ Prompts for a review date when the project should be reconsidered."
       (call-interactively #'org-gtd-tickler))
     (message "Project incubated")))
 
-;;;###autoload
-(defun org-gtd-project-someday-from-context ()
-  "Put the current project into someday/maybe.
-Works from graph view or agenda context."
-  (interactive)
-  (require 'org-gtd-someday)
-  (let ((project-marker (org-gtd-project--get-marker-from-context)))
-    (org-with-point-at project-marker
-      (call-interactively #'org-gtd-someday))
-    (message "Project moved to someday/maybe")))
-
 ;;;###autoload
 (defun org-gtd-project-cancel-from-context ()
   "Cancel the current project.
@@ -367,8 +306,10 @@ Works from graph view or agenda context.
 Marks all incomplete tasks in the project as canceled."
   (interactive)
   (let ((project-marker (org-gtd-project--get-marker-from-context)))
-    (org-with-point-at project-marker
-      (org-gtd-project-cancel))))
+    (when (yes-or-no-p "Really cancel this project? ")
+      (org-with-point-at project-marker
+        (org-gtd-project-cancel))
+      (message "Project canceled"))))
 
 ;;;###autoload
 (defun org-gtd-stuck-projects ()
@@ -384,20 +325,19 @@ constitutes a stuck project in the GTD system."
 
 ;;;###autoload
 (defun org-gtd-project-cancel ()
-  "With point on topmost project heading, mark all undone tasks canceled.
-Prompts for confirmation with the project heading name before canceling."
+  "With point on topmost project heading, mark all undone tasks canceled."
   (interactive)
-  (let ((heading-name (org-get-heading t t t t)))
-    (when (yes-or-no-p (format "Cancel project '%s'? " heading-name))
-      ;; Set project heading to CNCL if not already (guard prevents hook re-entry)
-      (setq org-gtd-project--cancel-in-progress t)
-      (unwind-protect
-          (unless (string= (org-get-todo-state) (org-gtd-keywords--canceled))
-            (let ((org-inhibit-logging 'note))
-              (org-todo (org-gtd-keywords--canceled))))
-        (setq org-gtd-project--cancel-in-progress nil))
-      ;; Cancel all incomplete child tasks
-      (org-gtd-project--cancel-children))))
+  (org-edna-mode -1)
+  ;; v4: No need for with-org-gtd-context - operation doesn't need macro bindings
+  (let ((task-markers (org-gtd-dependencies-collect-project-tasks (point-marker))))
+    (dolist (task-marker task-markers)
+      (org-with-point-at task-marker
+        (when (org-gtd-projects--incomplete-task-p)
+          (let ((org-inhibit-logging 'note))
+            (org-todo (org-gtd-keywords--canceled)))))))
+  (org-edna-mode 1)
+  ;; Save changes to disk
+  (save-buffer))
 
 ;;;###autoload
 (defun org-gtd-project-cancel-from-agenda ()
@@ -1025,42 +965,34 @@ Useful for weekly reviews or after bulk changes."
      "+ORG_GTD=\"Projects\""
      'agenda)))
 
-(defun org-gtd-project--active-p (project-id)
-  "Check if project with PROJECT-ID is active.
-A project is active if it has ORG_GTD=\"Projects\" and is not done or cancelled."
-  (when-let ((marker (org-id-find project-id 'marker)))
-    (org-with-point-at marker
-      (and (string= (org-entry-get (point) "ORG_GTD") org-gtd-projects)
-           (not (org-entry-is-done-p))))))
-
-(defun org-gtd-project--task-last-active-project-p (task-marker current-project-id)
-  "Check if CURRENT-PROJECT-ID is the last active project for task at TASK-MARKER.
-Returns t if no other active projects exist for this task."
-  (org-with-point-at task-marker
-    (let ((project-ids (org-entry-get-multivalued-property (point) "ORG_GTD_PROJECT_IDS")))
-      (not (seq-some
-            (lambda (pid)
-              (and (not (string= pid current-project-id))
-                   (org-gtd-project--active-p pid)))
-            project-ids)))))
-
 (defun org-gtd-project--save-state (marker)
   "Save ORG_GTD and TODO state at MARKER to PREVIOUS_* properties.
 
 Saves current ORG_GTD value to PREVIOUS_ORG_GTD property.
 Saves current TODO keyword to PREVIOUS_TODO property.
+Sets ORG_GTD to \\='Tickler\\='.
 Clears the TODO keyword.
 
-Does NOT set ORG_GTD to any value -- callers are responsible for
-setting the target type after calling this function."
+Skips tasks belonging to multiple projects (identified by
+multiple IDs in ORG_GTD_PROJECT_IDS property)."
   (org-with-point-at marker
-    (let ((current-org-gtd (org-entry-get (point) "ORG_GTD"))
-          (current-todo (org-entry-get (point) "TODO")))
-      (when current-org-gtd
-        (org-entry-put (point) "PREVIOUS_ORG_GTD" current-org-gtd))
-      (when current-todo
-        (org-entry-put (point) "PREVIOUS_TODO" current-todo))
-      (org-todo 'none))))
+    ;; Check if this is a multi-project task
+    (let ((project-ids (org-entry-get-multivalued-property (point) "ORG_GTD_PROJECT_IDS")))
+      (if (> (length project-ids) 1)
+          ;; Skip multi-project tasks
+          (message "Skipping multi-project task: %s" (org-get-heading t t t t))
+        ;; Normal tickler state
+        (let ((current-org-gtd (org-entry-get (point) "ORG_GTD"))
+              (current-todo (org-entry-get (point) "TODO")))
+          ;; Save current state
+          (when current-org-gtd
+            (org-entry-put (point) "PREVIOUS_ORG_GTD" current-org-gtd))
+          (when current-todo
+            (org-entry-put (point) "PREVIOUS_TODO" current-todo))
+          ;; Set tickler state
+          (org-entry-put (point) "ORG_GTD" org-gtd-tickler)
+          ;; Clear TODO keyword
+          (org-todo 'none))))))
 
 (defun org-gtd-project--restore-state (marker)
   "Restore ORG_GTD and TODO state at MARKER from PREVIOUS_* properties.
@@ -1199,76 +1131,16 @@ Does not check for external dependencies or multi-project tasks yet
                                       dep-names "\n")))
             (user-error "Tickler cancelled")))))
 
-    (let ((current-project-id (org-id-get)))
-      ;; Save state and set type for project heading
-      (org-gtd-project--save-state project-marker)
-      (org-entry-put (point) "ORG_GTD" org-gtd-tickler)
+    ;; Save and tickler project heading
+    (org-gtd-project--save-state project-marker)
 
-      ;; Set review date
-      (org-entry-put (point) org-gtd-timestamp (format "<%s>" review-date))
+    ;; Set review date
+    (org-entry-put (point) org-gtd-timestamp (format "<%s>" review-date))
 
-      ;; Save state and set type for all tasks
-      (let ((task-markers (org-gtd-project--get-all-tasks project-marker)))
-        (dolist (task-marker task-markers)
-          (if (org-gtd-project--task-last-active-project-p task-marker current-project-id)
-              (progn
-                (org-gtd-project--save-state task-marker)
-                (org-with-point-at task-marker
-                  (org-entry-put (point) "ORG_GTD" org-gtd-tickler)))
-            (message "Skipping multi-project task (other active projects): %s"
-                     (org-with-point-at task-marker
-                       (org-get-heading t t t t)))))))
-
-    ;; Save changes to disk
-    (save-buffer)))
-
-;;;###autoload
-(defun org-gtd-project-someday (project-marker)
-  "Put project at PROJECT-MARKER into someday/maybe.
-
-PROJECT-MARKER is a marker pointing to the project heading.
-
-Puts the project into someday/maybe by:
-1. Saving state for project heading and all tasks
-2. Setting ORG_GTD to Someday on everything
-3. Prompting for someday list if configured"
-  (interactive (list (point-marker)))
-
-  (org-with-point-at project-marker
-    ;; Check for external dependencies
-    (let ((external-deps (org-gtd-project--check-external-dependencies project-marker)))
-      (when external-deps
-        (let ((dep-names (mapcar (lambda (m)
-                                   (org-with-point-at m
-                                     (org-get-heading t t t t)))
-                                 external-deps)))
-          (unless (yes-or-no-p
-                   (format "External tasks depend on this project:\n%s\n\nContinue with someday? "
-                           (mapconcat (lambda (name) (format "  - %s" name))
-                                      dep-names "\n")))
-            (user-error "Someday cancelled")))))
-
-    (let ((current-project-id (org-id-get)))
-      ;; Save state and set type for project heading
-      (org-gtd-project--save-state project-marker)
-      (org-entry-put (point) "ORG_GTD" org-gtd-someday)
-
-      ;; Prompt for someday list if configured
-      (when org-gtd-someday-lists
-        (let ((list (completing-read "Someday list: " org-gtd-someday-lists nil t)))
-          (org-entry-put (point) org-gtd-prop-someday-list list)))
-
-      ;; Save state and set type for all tasks
-      (let ((task-markers (org-gtd-project--get-all-tasks project-marker)))
-        (dolist (task-marker task-markers)
-          (if (org-gtd-project--task-last-active-project-p task-marker current-project-id)
-              (progn
-                (org-gtd-project--save-state task-marker)
-                (org-with-point-at task-marker
-                  (org-entry-put (point) "ORG_GTD" org-gtd-someday)))
-            (message "Skipping multi-project task (other active projects): %s"
-                     (org-with-point-at task-marker
-                       (org-get-heading t t t t)))))))
+    ;; Tickler all tasks
+    (let ((task-markers (org-gtd-project--get-all-tasks project-marker)))
+      (dolist (task-marker task-markers)
+        (org-gtd-project--save-state task-marker)))
 
     ;; Save changes to disk
     (save-buffer)))
