@@ -517,43 +517,37 @@ Returns a string like \"LEVEL>0+ORG_GTD=\\\"Calendar\\\"/TODO=\\\"NEXT\\\"\"."
 (defun org-gtd-view-lang--build-skip-function-for-stuck-type (base-type)
   "Build a skip function for stuck items of BASE-TYPE.
 Stuck items are included if they have ANY missing/invalid metadata.
-Tasks from fully inactive (cancelled/done) projects are skipped.
 Returns a function suitable for `org-agenda-skip-function'."
   (let ((org-gtd-val (org-gtd-type-org-gtd-value base-type))
         (when-prop (org-gtd-type-property base-type :when))
-        (who-prop (org-gtd-type-property base-type :who))
-        (active-project-pred (org-gtd-pred--task-has-active-project)))
+        (who-prop (org-gtd-type-property base-type :who)))
     (lambda ()
       (let ((end (org-entry-end-position)))
         ;; Must match the base type
         (if (not (equal (org-entry-get (point) "ORG_GTD") org-gtd-val))
             end  ; Skip - wrong type
-          ;; Must belong to at least one active project (or have no project)
-          (if (not (funcall active-project-pred))
-              end  ; Skip - all projects inactive
-            ;; Item is stuck if ANY of the following are true:
-            ;; - Invalid timestamp (when type has :when property)
-            ;; - Missing/empty who (when type has :who property)
-            (let ((is-stuck nil))
-              (when when-prop
-                (let ((ts-value (org-entry-get (point) when-prop)))
-                  (when (or (not ts-value)
-                            (string-empty-p (string-trim ts-value))
-                            (not (string-match org-ts-regexp-both ts-value)))
-                    (setq is-stuck t))))
-              (when (and who-prop (not is-stuck))
-                (let ((who-value (org-entry-get (point) who-prop)))
-                  (when (or (not who-value)
-                            (string-empty-p (string-trim who-value)))
-                    (setq is-stuck t))))
-              (if is-stuck
-                  nil   ; Include - item is stuck
-                end)))))))) ; Skip - item is not stuck
+          ;; Item is stuck if ANY of the following are true:
+          ;; - Invalid timestamp (when type has :when property)
+          ;; - Missing/empty who (when type has :who property)
+          (let ((is-stuck nil))
+            (when when-prop
+              (let ((ts-value (org-entry-get (point) when-prop)))
+                (when (or (not ts-value)
+                          (string-empty-p (string-trim ts-value))
+                          (not (string-match org-ts-regexp-both ts-value)))
+                  (setq is-stuck t))))
+            (when (and who-prop (not is-stuck))
+              (let ((who-value (org-entry-get (point) who-prop)))
+                (when (or (not who-value)
+                          (string-empty-p (string-trim who-value)))
+                  (setq is-stuck t))))
+            (if is-stuck
+                nil   ; Include - item is stuck
+              end))))))) ; Skip - item is not stuck
 
 (defun org-gtd-view-lang--build-skip-function-for-project-type (project-type)
   "Build a skip function for computed PROJECT-TYPE.
-PROJECT-TYPE is one of stuck-project, active-project, completed-project.
-Done/cancelled projects are skipped from stuck-project and active-project views."
+PROJECT-TYPE is one of stuck-project, active-project, completed-project."
   (lambda ()
     (let ((end (org-entry-end-position)))
       ;; Must be a project
@@ -561,17 +555,13 @@ Done/cancelled projects are skipped from stuck-project and active-project views.
           end  ; Skip - not a project
         (cond
          ((eq project-type 'stuck-project)
-          (if (org-entry-is-done-p)
-              end  ; Skip - done/cancelled project
-            (if (funcall (org-gtd-pred--project-is-stuck))
-                nil    ; Include - project is stuck
-              end)))   ; Skip - project is not stuck
+          (if (funcall (org-gtd-pred--project-is-stuck))
+              nil    ; Include - project is stuck
+            end))    ; Skip - project is not stuck
          ((eq project-type 'active-project)
-          (if (org-entry-is-done-p)
-              end  ; Skip - done/cancelled project
-            (if (funcall (org-gtd-pred--project-has-active-tasks))
-                nil    ; Include - has active tasks
-              end)))   ; Skip - no active tasks
+          (if (funcall (org-gtd-pred--project-has-active-tasks))
+              nil    ; Include - has active tasks
+            end))    ; Skip - no active tasks
          ((eq project-type 'completed-project)
           (if (not (funcall (org-gtd-pred--project-has-active-tasks)))
               nil    ; Include - no active tasks (completed)
@@ -604,27 +594,22 @@ Matches items in Tickler OR Someday that were previously Projects."
 (defun org-gtd-view-lang--build-skip-function-for-stuck-single-action ()
   "Build a skip function for stuck-single-action type.
 Matches undone single actions (ORG_GTD=Actions) that are not in NEXT state.
-These need attention because single actions should always be in NEXT.
-Tasks from fully inactive (cancelled/done) projects are skipped."
+These need attention because single actions should always be in NEXT."
   (let ((actions-val (org-gtd-type-org-gtd-value 'next-action))
-        (next-keyword (org-gtd-keywords--next))
-        (active-project-pred (org-gtd-pred--task-has-active-project)))
+        (next-keyword (org-gtd-keywords--next)))
     (lambda ()
       (let ((end (org-entry-end-position)))
         ;; Must be an Actions item
         (if (not (equal (org-entry-get (point) "ORG_GTD") actions-val))
             end  ; Skip - not a single action
-          ;; Must belong to at least one active project (or have no project)
-          (if (not (funcall active-project-pred))
-              end  ; Skip - all projects inactive
-            ;; Must not be done
-            (if (org-entry-is-done-p)
-                end  ; Skip - done
-              ;; Is stuck if NOT in NEXT state
-              (let ((todo-state (org-entry-get (point) "TODO")))
-                (if (equal todo-state next-keyword)
-                    end   ; Skip - properly in NEXT state
-                  nil)))))))))
+          ;; Must not be done
+          (if (org-entry-is-done-p)
+              end  ; Skip - done
+            ;; Is stuck if NOT in NEXT state
+            (let ((todo-state (org-entry-get (point) "TODO")))
+              (if (equal todo-state next-keyword)
+                  end   ; Skip - properly in NEXT state
+                nil)))))))) ; Include - stuck (not in NEXT)
 
 (defun org-gtd-view-lang--done-filter-days (done-value)
   "Return the number of days to look back for DONE-VALUE filter.
@@ -889,8 +874,6 @@ The function composes predicates from the view spec filters."
         ;; Add todo keyword predicate
         (when-let ((todo-filter (alist-get 'todo gtd-view-spec)))
           (push (org-gtd-pred--todo-matches todo-filter) predicates))
-        ;; Exclude tasks from fully inactive projects
-        (push (org-gtd-pred--task-has-active-project) predicates)
         ;; Always exclude done items from native blocks
         (push (org-gtd-pred--not-done) predicates)
         ;; Compose predicates into skip function
